@@ -1,6 +1,6 @@
 class HexadecimalCipher:
     def __init__(self):
-        """ This is a python implementation of Binary Cipher. More about it can
+        """ This is a python implementation of Hexadecimal Cipher. More about it can
         be read here : https://en.wikipedia.org/wiki/Hexadecimal"""
 
     @staticmethod
